@@ -17,6 +17,10 @@ static const char *KEY_NAME[KEY_MAX] = {
 #include "evtable_BTN.inc"
 };
 
+static const char *REL_NAME[REL_MAX] = {
+#include "evtable_REL.inc"
+};
+
 static const char *SW_NAME[SW_MAX] = {
 #include "evtable_SW.inc"
 };
